@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model-Itself
 #
-# This software is Copyright (c) 2012 by Dominique Dumont.
+# This software is Copyright (c) 2013 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -146,7 +146,7 @@
                 type         => 'leaf',
                 class        => 'Config::Model::Itself::BackendDetector',
                 value_type   => 'enum',
-                choice       => [qw/cds_file perl_file ini_file augeas custom/],
+                choice       => [qw/cds_file perl_file ini_file custom/],
                 migrate_from => {
                     formula   => '$old',
                     variables => { old => '- syntax' },
@@ -165,9 +165,7 @@
 "file with a perl data structure. Configuration filename is made with instance name",
                     custom =>
 "Custom format. You must specify your own class and method to perform the read or write function. See Config::Model::AutoRead doc for more details",
-                    augeas =>
-"Experimental backend with RedHat's Augeas library. See http://augeas.net for details",
-                }
+               }
             },
 
             'file' => {
@@ -198,19 +196,6 @@
                 }
             },
 
-            'save' => {
-                type       => 'leaf',
-                value_type => 'enum',
-                choice     => [qw/backup newfile/],
-                level      => 'hidden',
-                description =>
-'Specify how to save the configuration file. Either create a newfile (with extension .augnew, and do not overwrite the original file) or move the original file into a backup file (.augsave extension). Configuration files are overwritten by default',
-                warp => {
-                    follow => '- backend',
-                    rules  => [ augeas => { level => 'normal', } ],
-                }
-            },
-
             'store_class_in_hash' => {
                 type       => 'leaf',
                 value_type => 'uniline',
@@ -339,32 +324,6 @@
                     rules  => [ ini_file => { level => 'normal', } ],
                 }
             },
-            'set_in' => {
-                type       => 'leaf',
-                value_type => 'reference',
-                refer_to   => '- - element',
-                level      => 'hidden',
-                description =>
-'Sometimes, the structure of a file loaded by Augeas starts directly with a list of items. For instance, /etc/hosts structure starts with a list of lines that specify hosts and IP addresses. This parameter specifies an element name in Config::Model root class that will hold the configuration data retrieved by Augeas',
-                warp => {
-                    follow => '- backend',
-                    rules  => [ augeas => { level => 'normal', } ],
-                }
-            },
-            'sequential_lens' => {
-                type  => 'list',
-                level => 'hidden',
-                cargo => {
-                    type       => 'leaf',
-                    value_type => 'uniline',
-                },
-                warp => {
-                    follow => { b                => '- backend' },
-                    rules  => [ '$b eq "augeas"' => { level => 'normal', } ],
-                },
-                description =>
-'List of hash or list Augeas lenses where value are stored in sequential Augeas nodes. See Config::Model::Backend::Augeas for details.',
-            },
         ],
 
     ],
@@ -468,7 +427,7 @@
         name => 'Itself::ConfigAccept',
 
         include       => "Itself::Element",
-        include_after => 'name_match',
+        include_after => 'accept_after',
         'element'     => [
             'name_match' => {
                 type             => 'leaf',
@@ -476,6 +435,14 @@
                 upstream_default => '.*',
                 status           => 'deprecated',
              },
+             'accept_after' => {
+                type => 'leaf',
+                value_type => 'reference' ,
+                refer_to => '- - element' ,
+                description => 'specify where to insert accepted element. This will'
+                 . ' change the behavior but will help generating more consistent '
+                 . ' user interfaces'
+             }
 
         ],
     ],
